@@ -4,6 +4,12 @@
 ( cd opt/kde/share/doc/HTML/sv/kdf ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kdm ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kig ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kig ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/juk ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/juk ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kpf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kpf ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/ktuberling ; rm -rf common )
@@ -18,8 +24,12 @@
 ( cd opt/kde/share/doc/HTML/sv/kdat ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kdvi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kdvi ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/kgeo ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/kgeo ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kget ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kget ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kgpg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kgpg ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kmag ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kmag ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kmid ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kmid ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kmix ; rm -rf common )
@@ -30,10 +40,14 @@
 ( cd opt/kde/share/doc/HTML/sv/kolf ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kpat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kpat ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kpdf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kpdf ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/korn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/korn ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kppp ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kppp ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/krdc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/krdc ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/krec ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/krec ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/krfb ; rm -rf common )
@@ -44,6 +58,8 @@
 ( cd opt/kde/share/doc/HTML/sv/ksim ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/lisa ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/lisa ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kxkb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kxkb ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kalzium ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kalzium ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/katomic ; rm -rf common )
@@ -52,6 +68,8 @@
 ( cd opt/kde/share/doc/HTML/sv/ksysguard ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kbounce ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kbounce ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kdearch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kdearch ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kbattleship ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kaboodle ; rm -rf common )
@@ -78,6 +96,8 @@
 ( cd opt/kde/share/doc/HTML/sv/kcron ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kdict ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kdict ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kedit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kedit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kfind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kfind ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kiten ; rm -rf common )
@@ -110,18 +130,28 @@
 ( cd opt/kde/share/doc/HTML/sv/kwin4 ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/lskat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/lskat ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kgoldrunner ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcoloredit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/klipper ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/klipper ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kvoctrain ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kmousetool ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kmousetool ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kompare ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kontact ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kontact ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/konsole ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/konsolekalendar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kcachegrind ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kpackage ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/khelpcenter/faq ; rm -rf common )
@@ -146,10 +176,16 @@
 ( cd opt/kde/share/doc/HTML/sv/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kverbos ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kwallet ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kwallet ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kweather ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kwuftpd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kxsldbg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kwifimanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kmenuedit ; rm -rf common )
@@ -160,8 +196,6 @@
 ( cd opt/kde/share/doc/HTML/sv/flashkard ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/aktion ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/aktion ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kxconfig ; rm -rf common )
@@ -202,6 +236,8 @@
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/sv/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf doxygen.css )
@@ -216,12 +252,16 @@
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/sv/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/sv/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf fdl-license.html )
@@ -296,10 +336,14 @@
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/kmixcfg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kcontrol/desktopbehavior ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/lanbrowser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/passwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kcontrol/panelappearance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/ebrowsing ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/background ; rm -rf common )
@@ -382,6 +426,8 @@
 ( cd opt/kde/share/doc/HTML/sv/konq-plugins/validators ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/konq-plugins/fsview ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/konq-plugins/fsview ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/konq-plugins/uachanger ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/konq-plugins/uachanger ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/konq-plugins/mediaplayer ; rm -rf common )
@@ -398,16 +444,24 @@
 ( cd opt/kde/share/doc/HTML/sv/kdeprint ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kasteroids ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kasteroids ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kbruch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kbruch ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/keduca ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/keduca ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kgamma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kgamma ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kdevelop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kdevelop ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kicker ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/klines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/klines ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kmines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kmines ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kmouth ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kmouth ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kmplot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kmplot ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/knotes ; rm -rf common )
@@ -416,6 +470,8 @@
 ( cd opt/kde/share/doc/HTML/sv/kpager ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kpaint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kpaint ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kopete ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kopete ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kpilot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kpilot ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kpoker ; rm -rf common )
@@ -442,6 +498,8 @@
 ( cd opt/kde/share/doc/HTML/sv/kreversi ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/noatun ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/noatun ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/ksplashml ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/ksplashml ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kblackbox ; rm -rf common )
@@ -452,14 +510,14 @@
 ( cd opt/kde/share/doc/HTML/sv/quanta ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kuickshow ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kde_app_devel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kiconedit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/klettres ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/klettres ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kfouleggs ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/kaphorism ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/kaphorism ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kghostview ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kghostview ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/klickety ; rm -rf common )
@@ -520,6 +578,8 @@
 ( cd opt/kde/share/doc/HTML/sv/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kate-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/umbrello ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/umbrello ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/konqueror ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/korganizer ; rm -rf common )
